import builtins as __builtins__;
from functools import wraps as _smart_deco_wrap;
from martialaw.martialaw import partial as _fical

def wither(opener = _fical(open, mode = 'w')):
	def with_deco(func):
		@_smart_deco_wrap(func)
		def with_opener(name, *argv, **kargv):
			with opener(name) as man:
				return func(man, *argv, **kargv)
		return with_opener
	return with_deco

write_the_text_file = wither()(lambda f, x : f.write(x))
read_the_text_file = wither(open)(lambda f : f.read())

class edprompt:
	def __neg__(self):
		res = _
		print(res)
		write_the_text_file(input("save as : "), res)
	
	def __pos__(self):
		global _
		res = _
		res = read_the_text_file(res)
		print(res)
		_ = res
		return res

__builtins__.y = edprompt()


from setuptools import setup, find_packages

setup(
    name='edprompt',
    version='0.0.5',
    description='python shell prompt cli editor joke saver prompt bloody hell lmao 🤣🤣🤣',
    author='du7ec',
    author_email='dutec6834@gmail.com',
    url='https://github.com/FarAway6834/edprompt',
    packages=find_packages(exclude=[]),
    install_requires=['clro'],
    keywords=['python', 'shell', 'prompt', 'cli', 'editer', 'joke' 'saver', 'edprompt'],
    python_requires='>=3.6',
    package_data={},
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Programming Language :: Python :: 3.14',
    ],
)
